@@ -24,12 +24,12 @@ from lxml import etree
 from random import choice
 
 try:
-    redis_cache = Redis(host='127.0.0.1', port=6379, decode_responses=True)
+    redis_db = Redis(host='127.0.0.1', port=6379, decode_responses=True)
 except:
     pass
 L = threading.Lock()
 Q = queue.Queue()
-logging.basicConfig(format='%(asctime)s - %(levelname)s: %(message)s', level=logging.DEBUG)
+logging.basicConfig(format='%(asctime)s - %(levelname)s: %(message)s', level=logging.INFO)
 requests.packages.urllib3.disable_warnings()
 
 
@@ -86,13 +86,12 @@ def cache(seconds=0, is_update=None):
             res = redis_db.get(key)
             if res:
                 return json.loads(res)
+        res = wrapped(*args, **kwargs)
+        if seconds > 0:
+            redis_db.set(key, json.dumps(res, cls=CJsonEncoder), ex=seconds)
         else:
-            res = wrapped(*args, **kwargs)
-            if seconds > 0:
-                redis_db.set(key, json.dumps(res, cls=CJsonEncoder), ex=seconds)
-            else:
-                redis_db.set(key, json.dumps(res, cls=CJsonEncoder))
-            return res
+            redis_db.set(key, json.dumps(res, cls=CJsonEncoder))
+        return res
 
     return wrapper
 
